@@ -8,6 +8,7 @@ import urllib2
 
 from nflgame import OrderedDict
 import nflgame.player
+import nflgame.schedule
 import nflgame.seq
 import nflgame.statmap
 
@@ -150,7 +151,7 @@ class GameClock (object):
         return self.qtr == 'Halftime'
 
     def is_final(self):
-        return self.qtr == 'Final' or self.qtr == 'final overtime'
+        return 'final' in self.qtr.lower()
 
     def __cmp__(self, other):
         if self.__qtr != other.__qtr:
@@ -222,6 +223,8 @@ class Game (object):
 
         When the JSON data is written to disk, it is compressed using gzip.
         """
+        # Make the schedule info more accessible.
+        self.schedule = nflgame.schedule.games_byid.get(self.eid, None)
 
         # Home and team cumulative statistics.
         self.home = self.data['home']['abbr']
@@ -230,6 +233,7 @@ class Game (object):
         self.stats_away = _json_team_stats(self.data['away']['stats']['team'])
 
         # Load up some simple static values.
+        self.gamekey = nflgame.schedule.games_byid[self.eid]['gamekey']
         self.time = GameClock(self.data['qtr'], self.data['clock'])
         self.down = _tryint(self.data['down'])
         self.togo = _tryint(self.data['togo'])
@@ -269,6 +273,14 @@ class Game (object):
         """Returns true if team (i.e., 'NE') is the home team."""
         return team == self.home
 
+    def season(self):
+        """Returns the year of the season this game belongs to."""
+        year = int(self.eid[0:4])
+        month = int(self.eid[4:6])
+        if month <= 3:
+            year -= 1
+        return year
+
     def game_over(self):
         """game_over returns true if the game is no longer being played."""
         return self.time.is_final()
